from ..cw_model import CWModel


class AccountingUnpostedProcurement(CWModel):

    def __init__(self, json_dict=None):
        self.id = None  # (Integer)
        self.description = None  # (String)
        self.locationId = None  # (Integer)
        self.departmentId = None  # (Integer)
        self.procurementType = None  # (Enum)
        self.purchaseOrder = None  # (PurchaseOrderReference)
        self.purchaseDate = None  # (String)
        self.trackingNumber = None  # (String)
        self.billingTerms = None  # (BillingTermsReference)
        self.currency = None  # (CurrencyReference)
        self.total = None  # (Number)
        self.taxCode = None  # (TaxCodeReference)
        self.avalaraTaxFlag = None  # (Boolean)
        self.itemTaxableFlag = None  # (Boolean)
        self.purchaseOrderTaxableFlag = None  # (Boolean)
        self.stateTaxFlag = None  # (Boolean)
        self.stateTaxXref = None  # (String)
        self.stateTaxAmount = None  # (Number)
        self.countyTaxFlag = None  # (Boolean)
        self.countyTaxXref = None  # (String)
        self.countyTaxAmount = None  # (Number)
        self.cityTaxFlag = None  # (Boolean)
        self.cityTaxXref = None  # (String)
        self.cityTaxAmount = None  # (Number)
        self.countryTaxFlag = None  # (Boolean)
        self.countryTaxXref = None  # (String)
        self.countryTaxAmount = None  # (Number)
        self.compositeTaxFlag = None  # (Boolean)
        self.compositeTaxXref = None  # (String)
        self.compositeTaxAmount = None  # (Number)
        self.taxTotal = None  # (Number)
        self.customer = None  # (CompanyReference)
        self.vendor = None  # (CompanyReference)
        self.vendorAccountNumber = None  # (String)
        self.vendorInvoiceNumber = None  # (String)
        self.vendorInvoiceDate = None  # (String)
        self.taxFreightFlag = None  # (Boolean)
        self.freightTaxTotal = None  # (Number)
        self.freightCost = None  # (Number)
        self.dateClosed = None  # (String)
        self._info = None  # (Metadata)
        
        # initialize object with json dict
        super().__init__(json_dict)
